Page MenuHomePhabricator

D7728.diff
No OneTemporary

D7728.diff

diff --git a/src/wallet/wallet.cpp b/src/wallet/wallet.cpp
--- a/src/wallet/wallet.cpp
+++ b/src/wallet/wallet.cpp
@@ -2436,8 +2436,9 @@
std::vector<COutPoint> lockedCoins;
ListLockedCoins(lockedCoins);
// Include watch-only for wallets without private keys
const bool include_watch_only =
+ GetLegacyScriptPubKeyMan() &&
IsWalletFlagSet(WALLET_FLAG_DISABLE_PRIVATE_KEYS);
const isminetype is_mine_filter =
include_watch_only ? ISMINE_WATCH_ONLY : ISMINE_SPENDABLE;
@@ -2436,8 +2436,9 @@
std::vector<COutPoint> lockedCoins;
ListLockedCoins(lockedCoins);
- // Include watch-only for wallets without private keys
+ // Include watch-only for LegacyScriptPubKeyMan wallets without private keys
const bool include_watch_only =

File Metadata

Mime Type
text/plain
Expires
Sat, Mar 1, 11:59 (47 m, 58 s)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
5187747
Default Alt Text
D7728.diff (601 B)

Event Timeline